@@ -7,6 +7,7 @@ from jet_bridge_base.views.message import MessageView
 from jet_bridge_base.views.model import ModelViewSet
 from jet_bridge_base.views.model_description import ModelDescriptionView
 from jet_bridge_base.views.register import RegisterView
+from jet_bridge_base.views.reload import ReloadView
 from jet_bridge_base.views.sql import SqlView
 from jet_django.route_view import route_view
 
@@ -28,6 +29,7 @@ def init_urls():
         url(r'^messages/', route_view(MessageView).as_view(), name='message'),
         url(r'^file_upload/', route_view(FileUploadView).as_view(), name='file-upload'),
         url(r'^image_resize/', route_view(ImageResizeView).as_view(), name='image-resize'),
+        url(r'^reload/', route_view(ReloadView).as_view(), name='reload'),
     ]
 
     api_urls = router.urls + extra_urls
